repos:

- repo: https://github.com/astral-sh/uv-pre-commit
  # ensure uv lockfile is synced when committing
  rev: 0.9.16
  hooks:
    - id: uv-lock
- repo: https://github.com/astral-sh/ruff-pre-commit
    # run linter and formmat code
  rev: v0.14.8
  hooks:
    # Run the linter.
    - id: ruff
      args: [ --fix ]
    # Run the formatter.
    - id: ruff-format
- repo: https://github.com/pre-commit/pre-commit-hooks
  rev: v6.0.0
  hooks:
  - id: check-merge-conflict
  - id: check-toml
  - id: check-yaml
    args: [--allow-multiple-documents]
  - id: debug-statements
  - id: detect-aws-credentials
    args: [--allow-missing-credentials]
  - id: detect-private-key
  - id: end-of-file-fixer
  - id: trailing-whitespace
- repo: https://github.com/codespell-project/codespell
  rev: v2.4.1
  hooks:
  - id: codespell
- repo: https://github.com/rhysd/actionlint
  rev: v1.7.9
  hooks:
    - id: actionlint
