.. {{ package_name }} documentation index file,
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Contents:

   usage
   CONTRIBUTING
   CHANGELOG

.. include:: readme.md
   :parser: myst_parser.sphinx_
