@import url('https://fonts.googleapis.com/css?family=Roboto|Roboto+Mono|Bungee%20Shade');

a {
    color: #027bab;
}

a:hover {
    color: #750076;
}

div.body h1 {
    color: #003d45;
    font-family: 'Bungee Shade';
    font-weight: bold;
    font-size: 275%;
}

ol.simple p,
ul.simple p {
    line-height: 150%;
}


div.sphinxsidebarwrapper h1.logo {
    text-align: center;
    margin: 20px 0 0 0;
}

div.sphinxsidebar p.blurb {
    font-size: 130%;
    line-height: 120%;
    text-align: center;
}

div.sphinxsidebar h1 a {
    font-size: 160%;
    color: #003d45;
    text-decoration: none;
    border: none;
}

div.sphinxsidebar h1 a:hover {
    border: none;
}

div.sphinxsidebar h3 {
    display: none;
}

div.sphinxsidebar a {
    color: #003d45;
}

code.descname {
    color: #6840ab;
}

th.field-name {
    min-width: 100px;
    color: #c5a3ff;
}

tt, code {
    color: #F8F8F2;
    background: #015259;
    border-radius: 0.3em;
    padding: 0.0em 0.3em;
}

a.reference.internal code.xref span.pre {
    color: #F8F8F2;
    background: #015259;
    border-bottom: none;
    border-radius: 0;
    padding: 0;
}

a.reference.internal, a.reference.internal:hover {
    border-bottom: none;
}

a.reference.internal:hover code {
    background: #027bab
}

a.reference.internal:hover code.xref span.pre {
    color: #F8F8F2;
    background: #027bab;
    border-bottom: none;
}

tt.xref, code.xref, a tt {
    background: none;
    border-bottom: none;
}

code.literal {
    color: #F8F8F2;
    background: #015259;
}

pre {
    padding: 20px 30px;
    background: #003038;
}

div > dl {
    border-left: 2px solid #00384021;
    padding-left: 5px;
}

dt {
    color: #027bab;
}

div.footer::before {
    display: block;
    content: '';
    border-top: 1px solid #999999;
    margin: 3em auto 2em auto;
}

div.footer {
    text-align: center;
    color: #029be2;
}

div.footer a {
    color: #027bab;
    text-decoration: none;
}

@media screen and (max-width: 940px) {
    body {
        margin: 0;
    }
    div.body {
        min-width: 0;
    }
    div.highlight {
        padding: 0px 5px;
    }
    div.sphinxsidebar {
        text-align: center;
    }
    div.sphinxsidebar h1 a {
        color: #f6f7f6;
    }
    div.sphinxsidebar a {
        color: #cdbde8;
    }
    div.sphinxsidebar ul {
        color: #ceb1ff;
    }
    div.sphinxsidebar ul ul {
        display: none;
    }
    div > dl {
        border: none;
        padding-left: none;
    }
}
